.. SPDX-FileCopyrightText: 2021 The meson-python developers

.. SPDX-License-Identifier: MIT

meson-python
============

``meson-python`` is a Python build backend built on top of the Meson__
build system. It enables to use Meson for the configuration and build
steps of Python packages. Meson is an open source build system meant
to be both extremely fast, and, even more importantly, as user
friendly as possible. ``meson-python`` is best suited for building
Python packages containing extension modules implemented in languages
such as C, C++, Cython, Fortran, Pythran, or Rust. Consult the
documentation__ for more details.

Questions regarding the use of ``meson-python`` can be directed to the
discussions__ space on GitHub. Bug reports and feature requests can be
filed as GitHub issues__.

__ https://mesonbuild.com/
__ https://meson-python.readthedocs.io/en/latest/
__ https://github.com/mesonbuild/meson-python/discussions/
__ https://github.com/mesonbuild/meson-python/issues/
